@@ -8,6 +8,8 @@ from devsecops_engine_tools.engine_core.src.domain.model.finding import (
 from dataclasses import dataclass
 from datetime import datetime
 import xml.etree.ElementTree as ET
+from packageurl import PackageURL
+from cpe import CPE
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
 from devsecops_engine_tools.engine_utilities import settings
 
@@ -37,14 +39,14 @@ class DependencyCheckDeserialize(DeserializatorGateway):
                     
                     id = vulnerability.find('ns:name', namespace).text[:20]
                     cvss = ", ".join(f"{child.tag.split('}')[-1]}: {child.text}" for child in vulnerability.find('ns:cvssV3', namespace)) if vulnerability.find('ns:cvssV3', namespace) else ""
-                    fileName = dependency.find('ns:fileName', namespace).text.split(":")[-1].strip()
+                    where = self.get_where(dependency, namespace)
                     description = vulnerability.find('ns:description', namespace).text if vulnerability.find('ns:description', namespace).text else ""
                     severity = vulnerability.find('ns:severity', namespace).text.lower()
-                    cvss
+                    
                     finding_open = Finding(
                         id=id,
                         cvss=cvss,
-                        where=fileName,
+                        where=where,
                         description=description[:120].replace("\n\n", " ").replace("\n", " ").strip() if len(description) > 0 else "No description available",
                         severity=severity,
                         identification_date=datetime.now().strftime("%d%m%Y"),
@@ -86,4 +88,68 @@ class DependencyCheckDeserialize(DeserializatorGateway):
             for dep in to_remove: dependencies.remove(dep)
             data_result.write(dependencies_scanned_file, encoding="utf-8", xml_declaration=True)
         
-        return dependencies, namespace
\ No newline at end of file
+        return dependencies, namespace
+
+    def get_where(self, dependency, namespace):
+        identifiers_node = dependency.find("ns:identifiers", namespace)
+        if identifiers_node:
+            package_node = identifiers_node.find(".//ns:package", namespace)
+            if package_node:
+                id = package_node.find("ns:id", namespace).text
+                purl = PackageURL.from_string(id)
+                purl_parts = purl.to_dict()
+                component_name = (
+                    purl_parts["namespace"] + ":"
+                    if purl_parts["namespace"]
+                    and len(purl_parts["namespace"]) > 0
+                    else ""
+                )
+                component_name += (
+                    purl_parts["name"]
+                    if purl_parts["name"] and len(purl_parts["name"]) > 0
+                    else ""
+                )
+                component_name = component_name or None
+                component_version = (
+                    purl_parts["version"]
+                    if purl_parts["version"] and len(purl_parts["version"]) > 0
+                    else ""
+                )
+                return f"{component_name}:{component_version}"
+
+            cpe_node = identifiers_node.find(
+                ".//ns:identifier[@type='cpe']", namespace
+            )
+            if cpe_node:
+                id = cpe_node.find("ns:name", namespace).text
+                cpe = CPE(id)
+                component_name = (
+                    cpe.get_vendor()[0] + ":"
+                    if len(cpe.get_vendor()) > 0
+                    else ""
+                )
+                component_name += (
+                    cpe.get_product()[0] if len(cpe.get_product()) > 0 else ""
+                )
+                component_name = component_name or None
+                component_version = (
+                    cpe.get_version()[0]
+                    if len(cpe.get_version()) > 0
+                    else None
+                )
+                return f"{component_name}:{component_version}"
+
+            maven_node = identifiers_node.find(
+                ".//ns:identifier[@type='maven']", namespace
+            )
+            if maven_node:
+                maven_parts = maven_node.find("ns:name", namespace).text.split(
+                    ":",
+                )
+
+                if len(maven_parts) == 3:
+                    component_name = maven_parts[0] + ":" + maven_parts[1]
+                    component_version = maven_parts[2]
+                    return f"{component_name}:{component_version}"
+
+        return ""
\ No newline at end of file
